
#line 3 "lex.swf4.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 33
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

#if __STDC__

#define YY_USE_CONST

#endif	/* __STDC__ */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE swf4restart(swf4in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int swf4leng;

extern FILE *swf4in, *swf4out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf4text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up swf4text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

/* The following is because we cannot portably get our hands on size_t
 * (without autoconf's help, which isn't available because we want
 * flex-generated scanners to compile on their own).
 */

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef unsigned int yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via swf4restart()), so that the user can continue scanning by
	 * just pointing swf4in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when swf4text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int swf4leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow swf4wrap()'s to do buffer switches
 * instead of setting up a fresh swf4in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void swf4restart (FILE *input_file  );
void swf4_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE swf4_create_buffer (FILE *file,int size  );
void swf4_delete_buffer (YY_BUFFER_STATE b  );
void swf4_flush_buffer (YY_BUFFER_STATE b  );
void swf4push_buffer_state (YY_BUFFER_STATE new_buffer  );
void swf4pop_buffer_state (void );

static void swf4ensure_buffer_stack (void );
static void swf4_load_buffer_state (void );
static void swf4_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER swf4_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE swf4_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE swf4_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE swf4_scan_bytes (yyconst char *bytes,int len  );

void *swf4alloc (yy_size_t  );
void *swf4realloc (void *,yy_size_t  );
void swf4free (void *  );

#define yy_new_buffer swf4_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        swf4ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf4_create_buffer(swf4in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        swf4ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            swf4_create_buffer(swf4in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *swf4in = (FILE *) 0, *swf4out = (FILE *) 0;

typedef int yy_state_type;

extern int swf4lineno;

int swf4lineno = 1;

extern char *swf4text;
#define yytext_ptr swf4text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up swf4text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	swf4leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 95
#define YY_END_OF_BUFFER 96
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[320] =
    {   0,
        0,    0,   96,   94,   56,   93,   94,   82,   94,   47,
       79,   94,   83,   84,   80,   77,   89,   78,   90,   81,
        1,   92,   75,   59,   76,   60,   91,   85,   86,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   87,   94,   88,   93,   64,
        0,   52,   50,    0,   47,    0,   65,    0,   53,   51,
        0,   67,   57,   69,   58,   70,   74,    0,   48,   54,
       48,   55,   68,    2,    1,   61,   63,   62,   47,   47,
       47,   47,   11,   47,   47,   47,   47,   47,   47,   47,
        9,   47,   47,   47,   47,   47,   47,   47,   47,   47,

       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   66,   72,   49,   49,   48,   48,    2,   73,
       71,   47,   47,   24,   47,   47,   47,   47,    8,   47,
       33,   47,   16,   47,   47,   47,   47,   23,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   49,   49,   47,   47,   47,
       47,   47,    7,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   37,   32,   47,   47,   47,   47,   47,   38,
       47,   47,   46,   14,   47,   47,    3,   47,   47,    5,
       47,   47,   47,   47,    4,   47,   47,   47,   47,   47,

       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   20,   47,   10,   47,   17,
       47,   47,   47,   47,   26,   47,   47,   15,   47,   47,
       47,   34,   47,   13,   47,   47,   47,   47,   47,   30,
       47,   47,   47,   47,   47,   47,   47,   47,   27,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   12,   47,    6,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   22,   47,   47,
       47,   25,   47,   47,   47,   47,   41,   28,   47,   35,
       36,   47,   44,   21,   47,   47,   47,   47,   47,   47,

       47,   47,   19,   40,   45,   47,   47,   43,   31,   42,
       47,   47,   47,   47,   47,   18,   29,   39,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    7,    1,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   18,
       18,   18,   18,   18,   18,   18,   18,   20,   21,   22,
       23,   24,   25,    1,   26,    7,   27,   28,    7,   29,
        7,    7,    7,    7,    7,   30,   31,    7,   32,   33,
       34,   35,   36,   37,   38,   39,    7,    7,    7,    7,
       40,   41,   42,    1,    7,    1,   43,   44,   45,   46,

       47,   48,   49,   50,   51,    7,   52,   53,   54,   55,
       56,   57,    7,   58,   59,   60,   61,   62,   63,   64,
       65,    7,   66,   67,   68,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    1,    1,
        1,    3,    1,    1,    1,    4,    5,    6,    6,    1,
        1,    1,    3,    1,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    1,
        1,    1,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[327] =
    {   0,
        0,    0,  642,  643,  643,  643,  638,  617,   66,  622,
      630,   67,  643,  643,  614,   58,  643,   59,   61,   63,
       69,  643,  643,  613,  612,  611,  643,  643,  643,   56,
       66,   67,   72,   74,   73,   76,   79,   80,   75,   81,
       95,   93,   94,   78,   96,  643,  566,  643,  643,  609,
      145,  152,  643,  628,  613,  613,  643,  140,  153,  643,
      625,  643,  643,  643,  643,  643,  610,  147,  609,  643,
       83,  643,  643,   83,   87,  601,  601,  643,  130,  143,
      140,  144,  606,  148,  149,  150,  151,  152,  154,  155,
      605,  156,  157,  158,  159,  161,  165,  163,  162,  166,

      167,  170,  168,  174,  175,  172,  180,  173,  183,  190,
      185,  193,  643,  643,  604,  102,  603,  602,  216,  643,
      643,  209,  187,  601,  201,  212,  219,  220,  598,  222,
      224,  225,  597,  226,  228,  230,  231,  593,  232,  233,
      236,  237,  238,  243,  241,  239,  242,  247,  246,  255,
      254,  250,  260,  251,  253,  592,  589,  252,  291,  267,
      265,  270,  575,  271,  272,  256,  274,  296,  269,  300,
      294,  275,  574,  565,  298,  307,  309,  311,  316,  317,
      318,  319,  564,  563,  320,  321,  562,  323,  325,  561,
      324,  326,  329,  330,  560,  327,  331,  332,  333,  334,

      341,  338,  347,  335,  343,  342,  344,  348,  349,   87,
      350,  357,  352,  360,  362,  559,  364,  555,  363,  554,
      366,  380,  382,  384,  385,  388,  394,  553,  395,  397,
      399,  552,  400,  550,  398,  401,  402,  403,  404,  549,
      405,  411,  413,  412,  407,  409,  415,  423,  546,  414,
      418,  416,  422,  427,  431,  434,  432,  419,  435,  436,
      439,  442,  542,  447,  541,  451,  454,  457,  458,  459,
      460,  461,  463,  465,  466,  469,  472,  540,  473,  475,
      480,  539,  478,  479,  476,  482,  538,  536,  484,  534,
      531,  485,  530,  529,  491,  492,  496,  501,  497,  499,

      503,  507,  528,  527,  524,  510,  514,  523,  522,  521,
      515,  513,  517,  516,  518,  520,  171,   77,  643,  583,
      588,  594,  599,  603,  606,  611
    } ;

static yyconst flex_int16_t yy_def[327] =
    {   0,
      319,    1,  319,  319,  319,  319,  319,  319,  320,  321,
      319,  322,  319,  319,  319,  319,  319,  319,  319,  323,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  319,  319,  319,  319,  319,
      320,  320,  319,  320,  321,  324,  319,  322,  322,  319,
      322,  319,  319,  319,  319,  319,  319,  323,  325,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  319,  319,  326,  319,  325,  319,  319,  319,
      319,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  326,  319,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,    0,  319,
      319,  319,  319,  319,  319,  319
    } ;

static yyconst flex_int16_t yy_nxt[712] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   21,   22,
       23,   24,   25,   26,   27,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   28,
        4,   29,   10,   30,   31,   32,   33,   34,   35,   10,
       36,   10,   37,   10,   38,   39,   40,   41,   42,   43,
       10,   44,   45,   10,   10,   46,   47,   48,   52,   59,
       63,   53,   56,   65,   70,   60,   67,   68,   71,   72,
       64,   66,   56,   56,   74,   73,   75,   75,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,  118,   68,

      119,  119,   74,   56,   75,   75,   54,   61,   80,   56,
       56,   56,   56,   79,  237,   81,   86,  157,   56,   89,
      111,   82,   83,   91,   85,   93,   95,   84,   90,   87,
       92,   88,   97,   98,   94,   96,   99,  101,  100,  103,
      106,  102,   59,  107,  108,  112,   56,   52,   60,  109,
       53,  110,  104,  105,   52,   59,   56,   53,  319,   56,
       56,   60,   71,  319,   56,   56,   56,   56,   56,  319,
       56,   56,   56,   56,   56,   56,  122,   56,   56,   56,
       61,   56,   56,   56,   56,   54,   56,   56,   56,   56,
       56,   56,   54,   61,  130,  123,   56,  124,  125,   56,

      135,   56,  128,   56,  126,  139,   56,  127,  129,   56,
      138,  134,  141,  131,  132,  133,  145,   56,  147,  137,
      140,  142,  136,  143,  148,   56,  150,  144,   56,  146,
      149,  151,  152,  119,  119,   56,   56,  154,   56,  159,
       56,   56,   56,  155,   56,  160,   56,   56,   56,   56,
      153,  158,   56,   56,   56,   56,  166,   56,   56,   56,
      161,  167,   56,   56,  162,  163,   56,   56,   56,   56,
       56,   56,   56,  170,  169,  165,   56,  172,  164,  178,
      168,   56,  176,   56,  167,   56,   56,   56,   56,  171,
       56,   56,  174,  177,  186,  180,  173,  175,  179,  182,

      181,  184,  185,  190,  183,  189,  187,   56,  198,  192,
       56,  188,   56,  197,   56,  193,   56,  195,  196,  191,
      194,  199,  204,   56,  200,   56,  206,   56,  201,  205,
      202,  198,   56,   56,   56,   56,   56,   56,  203,   56,
       56,   56,   56,   56,  211,   56,   56,   56,   56,   56,
       56,   56,  212,  209,   56,  214,  223,   56,   56,   56,
       56,  225,  207,   56,   56,   56,   56,  216,   56,  217,
      208,  218,  215,   56,  222,  210,   56,  213,   56,   56,
       56,  219,   56,  221,  225,  220,  224,  226,  232,  230,
      228,  227,  231,  229,  235,  243,   56,  234,   56,  233,

       56,   56,  241,  249,   56,  244,  236,  238,  242,  240,
       56,   56,  239,   56,   56,   56,   56,   56,   56,   56,
       56,   56,  246,   56,  256,   56,  245,   56,   56,   56,
       56,   56,   56,  250,   56,   56,  251,  247,   56,   56,
      248,  254,  255,   56,  262,  259,  269,   56,   56,  257,
       56,   56,   56,  265,  253,   56,  252,  267,   56,  258,
      263,  277,  261,   56,  260,  264,  271,   56,  266,  268,
       56,  270,  272,   56,   56,   56,   56,   56,  276,   56,
      273,   56,   56,  278,  274,   56,  275,  280,   56,   56,
      279,   56,   56,  282,   56,   56,   56,  283,   56,  284,

       56,   56,  281,  289,  298,  287,  288,   56,   56,  290,
      286,  291,   56,   56,  285,   56,  292,   56,  295,   56,
      294,  296,  297,   56,  301,  299,   56,  302,  293,   56,
       56,   56,   56,   56,   56,  300,   56,   56,   56,   56,
       56,  303,  308,   56,   56,   56,   56,   56,  306,  304,
       56,  305,   56,  307,   56,   56,   56,   56,   56,  311,
      312,  314,   56,  309,  313,   56,   56,  310,   56,   56,
       56,   56,  315,  316,  317,   56,   56,   56,   56,   56,
       56,   56,  318,   51,   51,   51,   51,   51,   51,   55,
       56,   56,   55,   55,   58,   58,   58,   58,   58,   58,

       69,   69,   69,   69,  115,   56,  115,  117,   56,   56,
      117,  117,  156,   56,   56,  156,  156,   56,   68,   68,
       56,   56,   56,  121,  120,   68,   68,  319,  116,   56,
      319,  114,  113,   78,   77,   76,   62,   57,   56,   50,
       49,  319,    3,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,

      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319
    } ;

static yyconst flex_int16_t yy_chk[712] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    9,   12,
       16,    9,   30,   18,   20,   12,   19,   19,   20,   20,
       16,   18,   31,   32,   21,   20,   21,   21,   33,   35,
       34,   39,   36,  318,   44,   37,   38,   40,   71,   71,

       74,   74,   75,  210,   75,   75,    9,   12,   31,   42,
       43,   41,   45,   30,  210,   31,   34,  116,  116,   35,
       44,   31,   32,   36,   33,   37,   38,   32,   35,   34,
       36,   34,   39,   40,   37,   38,   40,   41,   40,   42,
       43,   41,   58,   43,   43,   45,   79,   51,   58,   43,
       51,   43,   42,   42,   52,   59,   81,   52,   68,   80,
       82,   59,   68,   68,   84,   85,   86,   87,   88,   68,
       89,   90,   92,   93,   94,   95,   79,   96,   99,   98,
       58,   97,  100,  101,  103,   51,  102,  317,  106,  108,
      104,  105,   52,   59,   88,   80,  107,   81,   82,  109,

       94,  111,   86,  123,   84,   98,  110,   85,   87,  112,
       97,   93,  100,   89,   90,   92,  104,  125,  105,   96,
       99,  101,   95,  102,  106,  122,  108,  103,  126,  104,
      107,  109,  110,  119,  119,  127,  128,  111,  130,  123,
      131,  132,  134,  112,  135,  125,  136,  137,  139,  140,
      110,  122,  141,  142,  143,  146,  131,  145,  147,  144,
      125,  131,  149,  148,  126,  127,  152,  154,  158,  155,
      151,  150,  166,  135,  134,  130,  153,  137,  128,  144,
      132,  161,  142,  160,  131,  169,  162,  164,  165,  136,
      167,  172,  140,  143,  152,  146,  139,  141,  145,  148,

      147,  150,  151,  158,  149,  155,  153,  159,  167,  160,
      171,  154,  168,  166,  175,  161,  170,  164,  165,  159,
      162,  168,  171,  176,  168,  177,  175,  178,  169,  172,
      170,  167,  179,  180,  181,  182,  185,  186,  170,  188,
      191,  189,  192,  196,  180,  193,  194,  197,  198,  199,
      200,  204,  180,  178,  202,  182,  196,  201,  206,  205,
      207,  198,  176,  203,  208,  209,  211,  186,  213,  188,
      177,  189,  185,  212,  194,  179,  214,  181,  215,  219,
      217,  191,  221,  193,  198,  192,  197,  199,  205,  203,
      201,  200,  204,  202,  208,  217,  222,  207,  223,  206,

      224,  225,  214,  225,  226,  219,  209,  211,  215,  213,
      227,  229,  212,  230,  235,  231,  233,  236,  237,  238,
      239,  241,  222,  245,  235,  246,  221,  242,  244,  243,
      250,  247,  252,  226,  251,  258,  227,  223,  253,  248,
      224,  231,  233,  254,  242,  238,  250,  255,  257,  236,
      256,  259,  260,  245,  230,  261,  229,  247,  262,  237,
      243,  258,  241,  264,  239,  244,  252,  266,  246,  248,
      267,  251,  253,  268,  269,  270,  271,  272,  257,  273,
      254,  274,  275,  259,  255,  276,  256,  261,  277,  279,
      260,  280,  285,  264,  283,  284,  281,  266,  286,  267,

      289,  292,  262,  272,  283,  270,  271,  295,  296,  273,
      269,  274,  297,  299,  268,  300,  275,  298,  279,  301,
      277,  280,  281,  302,  286,  284,  306,  289,  276,  312,
      307,  311,  314,  313,  315,  285,  316,  310,  309,  308,
      305,  292,  299,  304,  303,  294,  293,  291,  297,  295,
      290,  296,  288,  298,  287,  282,  278,  265,  263,  302,
      306,  311,  249,  300,  307,  240,  234,  301,  232,  228,
      220,  218,  312,  313,  314,  216,  195,  190,  187,  184,
      183,  174,  315,  320,  320,  320,  320,  320,  320,  321,
      173,  163,  321,  321,  322,  322,  322,  322,  322,  322,

      323,  323,  323,  323,  324,  157,  324,  325,  156,  138,
      325,  325,  326,  133,  129,  326,  326,  124,  118,  117,
      115,   91,   83,   77,   76,   69,   67,   61,   56,   55,
       54,   50,   47,   26,   25,   24,   15,   11,   10,    8,
        7,    3,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,

      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int swf4_flex_debug;
int swf4_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *swf4text;
#line 1 "./swf4compiler.flex"
#line 2 "./swf4compiler.flex"

#include <math.h>
#include <string.h>
#include <stdlib.h>

#include "compile.h"
#include "actiontypes.h"
#include "blocks/error.h"
#include "swf4compiler.tab.h" /* defines token types */

static int swf4debug;

static const char *lexBuffer = NULL;
static int lexBufferLen = 0;

static int  sLineNumber = 0;
static char szLine[1024];
static char msgbufs[2][1024] = { {0}, {0} }, *msgline = {0};
static int  column = 0;

static void comment();
static void comment1();
static void count();
static void warning(char *msg);

#define YY_INPUT(buf,result,max_size) result=lexBufferInput(buf, max_size)

/* thanks to the prolific and brilliant Raff: */
static int lexBufferInput(char *buf, int max_size)
{
  int l = lexBufferLen > max_size ? max_size : lexBufferLen;
  
  if (lexBufferLen <= 0)
    return YY_NULL;

  memcpy(buf, lexBuffer, l);
  lexBuffer += l;
  lexBufferLen -= l;
  return l;
}

static void unescape(char *buf)
{
  char *r, *w;

  r=buf; // read
  w=buf; // write
  while (*r)
  {
	if ( *r == '\\' )
	{
		r++;
		switch(*r)
		{
			case 'b' : *w = '\b'; break;
			case 'f' : *w = '\f'; break;
			case 'n' : *w = '\n'; break;
			case 'r' : *w = '\r'; break;
			case 't' : *w = '\t'; break;
			case 'x' :
			case 'u' : fprintf(stderr,"unsupported escape sequence\n");
		}
		w++;
		r++;
	}
	else
	{
		*w++ = *r++;
	}
  }
  *w='\0';
}

void swf4ParseInit(const char *script, int debug, int version)
{
  checkByteOrder();
  swf4restart(NULL);

  swf4debug = debug;

  lexBuffer = script;
  lexBufferLen = strlen(script);
  sLineNumber = 0;
  column = 0;
  msgline = msgbufs[0];
  swfVersion = version;
}

#line 93 "./swf4compiler.flex"
 // forward declaration needed by the following function
#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif
 static void yyunput YY_PROTO(( int c, char *buf_ptr ));

 void do_unput4(const char c) { unput(c); }
#line 820 "lex.swf4.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int swf4wrap (void );
#else
extern int swf4wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO (void) fwrite( swf4text, swf4leng, 1, swf4out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( swf4in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( swf4in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, swf4in))==0 && ferror(swf4in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(swf4in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int swf4lex (void);

#define YY_DECL int swf4lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after swf4text and swf4leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 110 "./swf4compiler.flex"


#line 976 "lex.swf4.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! swf4in )
			swf4in = stdin;

		if ( ! swf4out )
			swf4out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			swf4ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				swf4_create_buffer(swf4in,YY_BUF_SIZE );
		}

		swf4_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of swf4text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 320 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 643 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 112 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text);
					return NUMBER; 		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 114 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text);
					return NUMBER; 		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 116 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup("1");
					return NUMBER;		}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 118 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup("0");
					return NUMBER;		}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 120 "./swf4compiler.flex"
{ count();	return BREAK;		}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 121 "./swf4compiler.flex"
{ count();	return CONTINUE;	}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 122 "./swf4compiler.flex"
{ count();	return ELSE;		}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 123 "./swf4compiler.flex"
{ count();	return FOR;		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 124 "./swf4compiler.flex"
{ count();	return IF;		}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 125 "./swf4compiler.flex"
{ count();	return WHILE;		}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 126 "./swf4compiler.flex"
{ count();	return DO;		}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 127 "./swf4compiler.flex"
{ count(); 	return EVAL;		}
	YY_BREAK
/* functions */
case 13:
YY_RULE_SETUP
#line 130 "./swf4compiler.flex"
{ count();	return RANDOM;	}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 131 "./swf4compiler.flex"
{ count();	return TIME;	}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 132 "./swf4compiler.flex"
{ count();	return LENGTH;	}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 133 "./swf4compiler.flex"
{ count();	return INT;	}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 134 "./swf4compiler.flex"
{ count();	return CONCAT;	}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 135 "./swf4compiler.flex"
{ count();	return DUPLICATECLIP;	}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 136 "./swf4compiler.flex"
{ count();	return REMOVECLIP;	}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 137 "./swf4compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 138 "./swf4compiler.flex"
{ count();	return STARTDRAG;	}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 139 "./swf4compiler.flex"
{ count();	return STOPDRAG;	}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 140 "./swf4compiler.flex"
{ count();	return ORD;	}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 141 "./swf4compiler.flex"
{ count();	return CHR;	}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 142 "./swf4compiler.flex"
{ count();	return CALLFRAME;	}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 143 "./swf4compiler.flex"
{ count();	return GETURL;	}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 144 "./swf4compiler.flex"
{ count();	return GETURL1;	}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 145 "./swf4compiler.flex"
{ count();	return LOADMOVIE;	}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 146 "./swf4compiler.flex"
{ count();	return LOADVARIABLES;	}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 147 "./swf4compiler.flex"
{ count();	return SUBSTR;	}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 149 "./swf4compiler.flex"
{ count();	return GETPROPERTY;	}
	YY_BREAK
/* getURL2 methods */
case 32:
YY_RULE_SETUP
#line 152 "./swf4compiler.flex"
{ count();	swf4lval.getURLMethod = GETURL_METHOD_POST;
				return GETURL_METHOD;	}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 154 "./swf4compiler.flex"
{ count();	swf4lval.getURLMethod = GETURL_METHOD_GET;
				return GETURL_METHOD;	}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 156 "./swf4compiler.flex"
{ count();	swf4lval.getURLMethod = GETURL_METHOD_NOSEND;
				return GETURL_METHOD;	}
	YY_BREAK
/* v3 functions */
case 35:
YY_RULE_SETUP
#line 161 "./swf4compiler.flex"
{ count();	return NEXTFRAME;	}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 162 "./swf4compiler.flex"
{ count();	return PREVFRAME;	}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 163 "./swf4compiler.flex"
{ count();	return PLAY;		}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 164 "./swf4compiler.flex"
{ count();	return STOP;		}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 165 "./swf4compiler.flex"
{ count();	return TOGGLEQUALITY;	}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 166 "./swf4compiler.flex"
{ count();	return STOPSOUNDS;	}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 167 "./swf4compiler.flex"
{ count();	return GOTOFRAME;	}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 168 "./swf4compiler.flex"
{ count();	return GOTOANDPLAY;	}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 169 "./swf4compiler.flex"
{ count();	return FRAMELOADED;	}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 170 "./swf4compiler.flex"
{ count();	return SETTARGET;	}
	YY_BREAK
/* high level functions */
case 45:
YY_RULE_SETUP
#line 173 "./swf4compiler.flex"
{ count();	return TELLTARGET;	}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 176 "./swf4compiler.flex"
{ count();      return THIS;	}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 178 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text);
					return IDENTIFIER;	}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 181 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text);
					return PATH;    }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 184 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text);
					return PATH;    }
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 187 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text+1);
					swf4lval.str[strlen(swf4lval.str)-1]=0;
                                        unescape(swf4lval.str);
					return STRING;		}
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 192 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup(swf4text+1);
					swf4lval.str[strlen(swf4lval.str)-1]=0;
                                        unescape(swf4lval.str);
					return STRING; 		}
	YY_BREAK
case 52:
/* rule 52 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf4text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf4text again */
YY_RULE_SETUP
#line 197 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 53:
/* rule 53 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up swf4text */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up swf4text again */
YY_RULE_SETUP
#line 201 "./swf4compiler.flex"
{ count();	swf4lval.str = strdup("");
					warning("Unterminated string!");
					return STRING;		}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 205 "./swf4compiler.flex"
{ count();	comment();		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 206 "./swf4compiler.flex"
{ count();	comment1();		}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 207 "./swf4compiler.flex"
{ count(); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 209 "./swf4compiler.flex"
{ count();	return INC; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 210 "./swf4compiler.flex"
{ count();	return DEC; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 211 "./swf4compiler.flex"
{ count();	return '<'; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 212 "./swf4compiler.flex"
{ count();	return '>'; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 213 "./swf4compiler.flex"
{ count();	return LE; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 214 "./swf4compiler.flex"
{ count();	return GE; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 215 "./swf4compiler.flex"
{ count();	return EQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 216 "./swf4compiler.flex"
{ count();	return NE; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 217 "./swf4compiler.flex"
{ count();	return LAN; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 218 "./swf4compiler.flex"
{ count();	return LOR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 219 "./swf4compiler.flex"
{ count();	return MEQ; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 220 "./swf4compiler.flex"
{ count();	return DEQ; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 221 "./swf4compiler.flex"
{ count();	return IEQ; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 222 "./swf4compiler.flex"
{ count();	return SEQ; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 223 "./swf4compiler.flex"
{ count();	return STREQ; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 224 "./swf4compiler.flex"
{ count();	return STRNE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 225 "./swf4compiler.flex"
{ count();	return STRCMP; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 226 "./swf4compiler.flex"
{ count();	return PARENT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 228 "./swf4compiler.flex"
{ count();	return ';'; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 229 "./swf4compiler.flex"
{ count();	return '='; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 230 "./swf4compiler.flex"
{ count();	return '+'; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 231 "./swf4compiler.flex"
{ count();	return '-'; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 232 "./swf4compiler.flex"
{ count();	return '&'; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 233 "./swf4compiler.flex"
{ count();	return '*'; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 234 "./swf4compiler.flex"
{ count();	return '/'; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 235 "./swf4compiler.flex"
{ count();	return '!'; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 236 "./swf4compiler.flex"
{ count();	return '('; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 237 "./swf4compiler.flex"
{ count();	return ')'; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 238 "./swf4compiler.flex"
{ count();	return '['; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 239 "./swf4compiler.flex"
{ count();	return ']'; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 240 "./swf4compiler.flex"
{ count();	return '{'; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 241 "./swf4compiler.flex"
{ count();	return '}'; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 242 "./swf4compiler.flex"
{ count();	return ','; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 243 "./swf4compiler.flex"
{ count();	return '.'; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 244 "./swf4compiler.flex"
{ count();	return '?'; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 245 "./swf4compiler.flex"
{ count();	return ':'; }
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 247 "./swf4compiler.flex"
{ count();	column = 0;
					strcpy(szLine, swf4text + 1);
					++sLineNumber;	yyless(1);	}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 251 "./swf4compiler.flex"
printf( "Unrecognized character: %s\n", swf4text );
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 253 "./swf4compiler.flex"
ECHO;
	YY_BREAK
#line 1571 "lex.swf4.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed swf4in at a new source and called
			 * swf4lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = swf4in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( swf4wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * swf4text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of swf4lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					swf4realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			swf4restart(swf4in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 320 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 320 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 319);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up swf4text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					swf4restart(swf4in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( swf4wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve swf4text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void swf4restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        swf4ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            swf4_create_buffer(swf4in,YY_BUF_SIZE );
	}

	swf4_init_buffer(YY_CURRENT_BUFFER,input_file );
	swf4_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void swf4_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		swf4pop_buffer_state();
	 *		swf4push_buffer_state(new_buffer);
     */
	swf4ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	swf4_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (swf4wrap()) processing, but the only time this flag
	 * is looked at is after swf4wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void swf4_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	swf4in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE swf4_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) swf4alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf4_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) swf4alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf4_create_buffer()" );

	b->yy_is_our_buffer = 1;

	swf4_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with swf4_create_buffer()
 * 
 */
    void swf4_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		swf4free((void *) b->yy_ch_buf  );

	swf4free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a swf4restart() or at EOF.
 */
    static void swf4_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	swf4_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then swf4_init_buffer was _probably_
     * called from swf4restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void swf4_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		swf4_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void swf4push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	swf4ensure_buffer_stack();

	/* This block is copied from swf4_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from swf4_switch_to_buffer. */
	swf4_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void swf4pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	swf4_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		swf4_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void swf4ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf4alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)swf4realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE swf4_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) swf4alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in swf4_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	swf4_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to swf4lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       swf4_scan_bytes() instead.
 */
YY_BUFFER_STATE swf4_scan_string (yyconst char * yystr )
{
    
	return swf4_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to swf4lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE swf4_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) swf4alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in swf4_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = swf4_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in swf4_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up swf4text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		swf4text[swf4leng] = (yy_hold_char); \
		(yy_c_buf_p) = swf4text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		swf4leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int swf4get_lineno  (void)
{
        
    return swf4lineno;
}

/** Get the input stream.
 * 
 */
FILE *swf4get_in  (void)
{
        return swf4in;
}

/** Get the output stream.
 * 
 */
FILE *swf4get_out  (void)
{
        return swf4out;
}

/** Get the length of the current token.
 * 
 */
int swf4get_leng  (void)
{
        return swf4leng;
}

/** Get the current token.
 * 
 */

char *swf4get_text  (void)
{
        return swf4text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void swf4set_lineno (int  line_number )
{
    
    swf4lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see swf4_switch_to_buffer
 */
void swf4set_in (FILE *  in_str )
{
        swf4in = in_str ;
}

void swf4set_out (FILE *  out_str )
{
        swf4out = out_str ;
}

int swf4get_debug  (void)
{
        return swf4_flex_debug;
}

void swf4set_debug (int  bdebug )
{
        swf4_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from swf4lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    swf4in = stdin;
    swf4out = stdout;
#else
    swf4in = (FILE *) 0;
    swf4out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * swf4lex_init()
     */
    return 0;
}

/* swf4lex_destroy is for both reentrant and non-reentrant scanners. */
int swf4lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		swf4_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		swf4pop_buffer_state();
	}

	/* Destroy the stack itself. */
	swf4free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * swf4lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *swf4alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *swf4realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void swf4free (void * ptr )
{
	free( (char *) ptr );	/* see swf4realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 253 "./swf4compiler.flex"


static int getinput() {
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
}

int swf4wrap()
{
  return 1;
}

static void countline()
{
  if(sLineNumber != 0)
    msgline[column] = 0;

  ++sLineNumber;
  column = 0;
  msgline = msgbufs[sLineNumber & 1];
}

static int LineNumber(void)
{
   return (sLineNumber + 1);
}

static int ColumnNumber(void)
{
   return column;
}

static char *LineText(void)
{
  msgline[column] = 0;
  return msgline;
}

static void comment(void)
{
   // Handle block comments

   int c, c1;

loop:
   // We have the start of a comment so look skip everything up to the
   // end of the comment character
   while ((c = getinput()) != '*' && c != EOF)
   {
      if(column < 1023)
         msgline[column] = c;

      ++column;

      // keep the line number in synch
      if (c == '\n')
      {
         // start the output (matches the algorithim in the lexx above)
	 countline();
      }

      if (swf4debug) putchar(c);
   }

   // is this the end of comment character
   if ((c1 = getinput()) != '/' && c != EOF)
   {
      // false start as this was no end of comment
      do_unput4(c1);
      goto loop;
   }

   // write out the start of the end of comment
   if (c != EOF)
      if (swf4debug) putchar(c);

   // write out the end of the end of comment
   if (c1 != EOF) 
      if (swf4debug) putchar(c1);
}

static void comment1(void)
{
   // Handle comment of type 1 (ie '//')

   int c;

   // this is a line comment
   while ((c = getinput()) != '\n' && c != EOF)
   {
      if (swf4debug) putchar(c);

      if(column < 1023)
         msgline[column] = c;

      ++column;
   };

   // keep the line number in synch
   if (c == '\n')
   {
      if (swf4debug) putchar(c);

      countline();
   }
}

static void count(void)
{
   int n;

   // Count the characters to maintain the current column position
   if (swf4text[0] == '\n')
   {
      if (swf4debug) printf("\n");
   }
   else
   {
      if (swf4debug) printf("%s", swf4text);

      for(n=0; n<swf4leng; ++n, ++column)
      {
	if(column < 1023)
	  msgline[column] = swf4text[n];
      }

      //-- keep writing the stuff to standard output
      //column += swf4leng;
   }
}

static void printprog()
{
  if(sLineNumber)
    SWF_warn("\n%s", msgbufs[(sLineNumber-1)&1]);

  if(column < 1023)
    msgline[column] = 0;

  SWF_warn("\n%s", msgline);
}

static void warning(char *msg)
{
   // print a warning message
   printprog();
   SWF_warn("\n%*s", ColumnNumber(), "^");
   SWF_warn("\nLine %4.4d:  Reason: '%s' \n", LineNumber(), msg);
}

void swf4error(char *msg)
{
  // report a error
  if(strlen(swf4text))
  {
    SWF_error("\n%s\n%*s\nLine %i:  Reason: '%s'\n",
	      LineText(), ColumnNumber(), "^", LineNumber(), msg);
  }
  else
  {
    SWF_error("\nLine %d: Reason: 'Unexpected EOF found while looking for input.'\n", LineNumber());
  }
}

